from django.shortcuts import get_object_or_404
from django.http import HttpResponse, HttpResponseRedirect
import models
import xml.dom.minidom as minidom
from xml_utils import children
from django.template.loader import render_to_string

from jumbo.shortcuts import render_to_response
from idashboard.gadgets import find_gadgets, open_gadget
from django.template.context import RequestContext
from django.views.decorators.csrf import csrf_exempt
#------------------------------------------------------------------------------

def dashboard(request, name):
    try:
        if request.user.is_authenticated():
            dashboard = models.IDashboard.objects.get(name=name,
                                                      user=request.user)
        else:
            dashboard = models.IDashboard.objects.get(name=name,
                                                      user=None)
    except models.IDashboard.DoesNotExist:
        if request.user.is_authenticated():
            dashboard = models.IDashboard(name=name, user=request.user,
                                          layout='three')
        else:
            dashboard = models.IDashboard(name=name, user=None, layout='three')
        dashboard.save()
    dashboard_data = {}
    column_data = []

    dashboard_items = models.IDashboardItem.objects.filter(dashboard=dashboard).order_by('column_number','position')

    column_number=0

    for gadget in dashboard_items:
        if gadget.column_number != column_number and column_number != 0:
            dashboard_data[column_number] = column_data
            column_data = []
        column_number = gadget.column_number
        column_data.append(render_to_string('idashboard/gadget.html', { 'gadget': gadget }))
    if len(dashboard_items)>0:
        dashboard_data[column_number] = column_data

    return render_to_response('idashboard/layouts/%s.html' % (dashboard.layout),
                              name=name,
                              dashboard_data=dashboard_data,
                              dashboard_items=dashboard_items)

#------------------------------------------------------------------------------

@csrf_exempt
def update_ajax(request, name):
    try:
        if request.user.is_authenticated():
            dashboard = models.IDashboard.objects.get(name=name,
                                                      user=request.user)
        else:
            dashboard = models.IDashboard.objects.get(name=name,
                                                      user=None)
    except models.IDashboard.DoesNotExist:
        if request.user.is_authenticated():
            dashboard = models.IDashboard(name=name, user=request.user)
        else:
            dashboard = models.IDashboard(name=name, user=None)
    models.IDashboardItem.objects.filter(dashboard=dashboard
                                         ).update(active=False)
    if request.method == 'POST':
        #TODO filtrare caratteri non validi tipo e commerciale
        dom = minidom.parseString(request.POST["xml"])
        parent = children(dom, 'xml')[0]
        column_nodes = children(parent, 'column')
        column_number=1
        for column_node in column_nodes:
            position=1
            gadget_nodes = children(column_node, 'gadget')
            for gadget_node in gadget_nodes:
                dashboard_item = models.IDashboardItem.objects.get(
                                            uuid=gadget_node.getAttribute('id'))
                dashboard_item.active = True
                dashboard_item.column_number = column_number
                dashboard_item.position = position
                dashboard_item.title = gadget_node.getAttribute('title')
                dashboard_item.colour = gadget_node.getAttribute('colour')
                if gadget_node.getAttribute('collapsed') == 'false':
                    dashboard_item.collapsed = False
                else:
                    dashboard_item.collapsed = True
                if len(gadget_node.childNodes) > 0:
                    mods = '<xml>'
                    for gn in gadget_node.childNodes:
                        mods += gn.toxml()
                    mods += '</xml>'
                    dashboard_item.modifier = mods
                dashboard_item.save()
                position = position+1
            column_number = column_number+1
        models.IDashboardItem.objects.filter(dashboard=dashboard,
                                             active=False).delete()
    return HttpResponse("<xml>Done</xml>")

#------------------------------------------------------------------------------

def gadget(request,uuid):
    dashboard_item = get_object_or_404(models.IDashboardItem,uuid=uuid)
    w = open_gadget(dashboard_item.gadget)
    return (w.view(request,dashboard_item))

#------------------------------------------------------------------------------

def view_gadgets(request,name):
    return render_to_response('idashboard/view_gadgets.html', name=name,
                              gadgets=find_gadgets())

#------------------------------------------------------------------------------

def add_gadget(request, name, gadget):
    try:
        if request.user.is_authenticated():
            dashboard = models.IDashboard.objects.get(name=name, 
                                                      user=request.user)
        else:
            dashboard = models.IDashboard.objects.get(name=name, user=None)
    except models.IDashboard.DoesNotExist:
        if request.user.is_authenticated():
            dashboard = models.IDashboard(name=name, user=request.user)
        else:
            dashboard = models.IDashboard(name=name, user=None)
    dashboard_item = models.IDashboardItem(dashboard=dashboard)
    dashboard_item.active = True
    dashboard_item.collapsed = False
    dashboard_item.position = 100
    dashboard_item.column_number = 1
    dashboard_item.gadget = gadget
    dashboard_item.title = open_gadget(gadget).gadget_info()['title']
    dashboard_item.save()
    # simone cittadini
    # rientra di [nome_dashb] / add / [nome_gadget] definiti nella url
    url = "../../../%s/" % (name)
    return HttpResponseRedirect(url)

#------------------------------------------------------------------------------

def show_layouts(request,name):
    return render_to_response('idashboard/layouts/index.html', name=name)

#------------------------------------------------------------------------------
@csrf_exempt
def save_layouts(request,name,layout):
    if request.user.is_authenticated():
        dashboard = get_object_or_404(models.IDashboard, name=name,
                                      user=request.user)
    else:
        dashboard = get_object_or_404(models.IDashboard, name=name, user=None)
    dashboard.layout=layout
    dashboard.save()

    if layout == 'two':
        models.IDashboardItem.objects.filter(dashboard=dashboard,
                                             column_number__gt=3
                                             ).update(column_number=1)
    # simone cittadini
    # rientra di [nome_dash_b] / [nome_layout] / save_layouts definiti nella url
    url = "../../../%s/" %(name)
    return HttpResponseRedirect(url)
