# -*- coding: utf-8 -*-
'''
Created on 13/lug/2011

@author: simone cittadini
'''
import os
import string

from django.db import models
from django.http import Http404

from settings import DOCUMENT_ROOT, DOCUMENT_URL


class DirectoryMetaData(models.Model):
    rpath = models.CharField(max_length=200, unique=True)
    titolo = models.CharField(max_length=128, blank=True, null=True)
    sottotitolo = models.CharField(max_length=256, blank=True, null=True)
    descrizione = models.CharField(max_length=512, blank=True, null=True)
    
    def __unicode__(self):
        return self.rpath


class FileSystemLink(models.Model):
    # nome del file (se è un file)
    name = models.CharField(max_length=64, null=True, blank=True)
    # path relativo alla MEDIA_ROOT
    rpath = models.CharField(max_length=200)

    
    class Meta:
        abstract = True
        
    def __unicode__(self):
        if self.name:
            return "FILE: %s - %s" % (self.rpath, self.name)
        else:
            return "DIR: %s" % self.rpath
    
    @staticmethod
    def get_files_under(rpath):
        """
        Torna una lista di files e directory sotto un path relativo a MEDIA_ROOT
        """
        path_string = "%s%s" % (DOCUMENT_ROOT, rpath)
        path = os.path.join(path_string)
        output = []
        print path_string
        if not os.path.exists(path):
            raise Http404()

        listdir = os.listdir(path)
        listdir.sort()
        for f in listdir:
            if os.path.isdir(os.path.join(path, f)):
                output.append(JcmsDirectory(
                        name=None,
                        rpath="%s/%s" % (rpath, f),
                        ))
            else:
                output.append(JcmsFile(
                        name=f,
                        rpath=rpath,
                        ))
        return output
    
    @staticmethod
    def get_metadata(rpath):
        """
        Torna un oggetto presistente con informazioni aggiuntive sulla directory
        """
        try:
            return DirectoryMetaData.objects.get(rpath=rpath)
        except:
            return None


class JcmsFile(FileSystemLink):
    
    class Meta:
        ordering = ('name',)
    
    def is_dir(self):
        return False
    
    def is_file(self):
        return not self.is_dir()
    
    def get_download_url(self):
        return "%s" % os.path.join(DOCUMENT_URL,self.rpath, self.name)
    
    def get_nice_name(self):
        parole = self.name.replace('_', ' ')
        return string.capwords(parole)
    
    def get_nice_name_acomea(self):
        return self.get_nice_name().replace('Acomea', 'AcomeA')


class JcmsDirectory(FileSystemLink):
    
    class Meta:
        ordering = ('rpath',)
    
    def is_dir(self):
        return True
    
    def is_file(self):
        return not self.is_dir()
    
    def get_download_url(self):
        return None
    
    def get_nice_name(self):
        # si possono ordinare le dire mettendo davnti al nome 0nn_
        splitted = self.rpath.split('/')
        nome = splitted[len(splitted)-1]
        if nome[0:1] == '0':
            nome = nome[3:]
        parole = nome.replace('_', ' ')
        return string.capwords(parole)
    
    def get_nice_name_acomea(self):
        return self.get_nice_name().replace('Acomea', 'AcomeA')
    
    def get_subdirs(self):
        return FileSystemLink.get_files_under(self.rpath)
    
    def get_there_are_subdirs(self):
        for f in FileSystemLink.get_files_under(self.rpath):
            if f.is_dir():
                return True
        return False
