# -*- coding: utf-8 -*-
'''
Created on 28/giu/2011

@author: simone cittadini
'''
import datetime

from django.views.generic.list_detail import object_list

from jumbo.shortcuts import render_to_response
from jcmspress.models import AreaPress, Press
from jcmspress.forms import RicercaPressForm
from fondi.models import AreaCategorie


def retrieve_aree(request):
    return object_list(request,
                       AreaPress.objects.all())
    
def retrieve_press(request, area_id=None, anno=None, mese=None, testata=None,
                   parola_chiave=None):
    """
    Ritorna uno o tutti gli oggetti AreaPress, eventualmente con le press
    contenute filtrare in base ad un certo mese.
    """
    filtered = False
    if request.method == 'POST':
        filtered=True
        form = RicercaPressForm(request.POST)
        if form.is_valid():
            if form.cleaned_data['sezione'] == 'None':
                area_id = None
            else:
                area_id = form.cleaned_data['sezione']
            if form.cleaned_data['meseanno'] == 'None':
                anno, mese = None, None
            else:
                anno = form.cleaned_data['meseanno'][0:4]
                mese = form.cleaned_data['meseanno'][5:7]
            if form.cleaned_data['testata'] == 'None':
                testata = None
            else:
                testata = form.cleaned_data['testata']
            parola_chiave = form.cleaned_data['parola_chiave']
    else:
        form = RicercaPressForm()

    today = datetime.date.today()
    container_aree = []
    if area_id:
        aree_qs = AreaPress.objects.filter(pk__exact=area_id)
    else:
        aree_qs = AreaPress.objects.all()
    if not filtered:
        for area_press in aree_qs:
            container_aree.append({'area': area_press})
#            container_aree[area_press.ordinale_pagina]['area'] = area_press
        return render_to_response('jcmspress/press_list.html',
                                  container_aree = container_aree,
                                  current_year = today.year,
                                  current_month = today.month,
                                  current_day = today.day,
                                  form = form)
#    container_aree = []
    for area_press in aree_qs:
        if anno==None or mese==None:
            qs = Press.objects.filter(area_press__exact=area_press)
        else:
            start_date = datetime.date(int(anno), int(mese), 1)
            end_date = datetime.date(int(anno), int(mese) + 1, 1)
            qs = Press.objects.filter(area_press__exact=area_press,
                                  date_p__range=(start_date, end_date))
        if testata != None:
            qs = qs.filter(title__exact=testata)
        if parola_chiave != None:
            qs = qs.filter(abstract__icontains=parola_chiave)
        if qs.count() > 0:
            container_aree.append({'area': area_press, 'presses' : qs.reverse()})
            #container_aree[area_press.ordinale_pagina]['area'] = area_press
            #container_aree[area_press.ordinale_pagina]['presses'] = qs
    return render_to_response('jcmspress/press_list_filtered.html',
                              container_aree = container_aree,
                              current_year = today.year,
                              current_month = today.month,
                              current_day = today.day,
                              form = form)
    
def retrieve_press_sezione(request, slug):
    if request.method == 'POST':
        return retrieve_press(request)
    form = RicercaPressForm()
    area = AreaPress.objects.get(slug=slug)
    return render_to_response('jcmspress/press_list_sezione.html',
                              area=area,
                              form=form)

    
def dettaglio_press(request, pk):
    press = Press.objects.get(pk=pk)
    return render_to_response('jcmspress/dettaglio_press.html',
                              press = press)
